# flake8: noqa

# import apis into api package
from sparkfly.api.audiences_api import AudiencesApi
from sparkfly.api.authentication_api import AuthenticationApi
from sparkfly.api.bi_store_lists_api import BIStoreListsApi
from sparkfly.api.campaigns_api import CampaignsApi
from sparkfly.api.credentials_api import CredentialsApi
from sparkfly.api.ctm_api import CtmApi
from sparkfly.api.eligible_item_sets_api import EligibleItemSetsApi
from sparkfly.api.email_opt_in_api import EmailOptInApi
from sparkfly.api.event_notifications_api import EventNotificationsApi
from sparkfly.api.impressions_api import ImpressionsApi
from sparkfly.api.items_api import ItemsApi
from sparkfly.api.member_privacy_api import MemberPrivacyApi
from sparkfly.api.members_api import MembersApi
from sparkfly.api.offer_lists_api import OfferListsApi
from sparkfly.api.offer_pos_offer_codes_api import OfferPOSOfferCodesApi
from sparkfly.api.offer_states_api import OfferStatesApi
from sparkfly.api.offers_api import OffersApi
from sparkfly.api.pos_offer_codes_api import POSOfferCodesApi
from sparkfly.api.store_lists_api import StoreListsApi
from sparkfly.api.stores_api import StoresApi
from sparkfly.api.templates_api import TemplatesApi
from sparkfly.api.transactions_api import TransactionsApi

