# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.eligible_item_sets_api import EligibleItemSetsApi


class TestEligibleItemSetsApi(unittest.IsolatedAsyncioTestCase):
    """EligibleItemSetsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = EligibleItemSetsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_eligible_item_set(self) -> None:
        """Test case for create_eligible_item_set

        Create an Eligible Item Set
        """
        pass

    async def test_delete_eligible_item_set(self) -> None:
        """Test case for delete_eligible_item_set

        Remove an Eligible Item Set
        """
        pass

    async def test_get_eligible_item_set(self) -> None:
        """Test case for get_eligible_item_set

        Get an Eligible Item Set
        """
        pass

    async def test_list_eligible_item_sets(self) -> None:
        """Test case for list_eligible_item_sets

        List all Eligible Item Sets
        """
        pass

    async def test_update_eligible_item_set(self) -> None:
        """Test case for update_eligible_item_set

        Update an Eligible Item Set
        """
        pass


if __name__ == '__main__':
    unittest.main()
