# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.ctm_api import CtmApi


class TestCtmApi(unittest.IsolatedAsyncioTestCase):
    """CtmApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CtmApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_ctm_allocate(self) -> None:
        """Test case for ctm_allocate

        CTM Allocate
        """
        pass

    async def test_ctm_create_member(self) -> None:
        """Test case for ctm_create_member

        CTM Update Response
        """
        pass

    async def test_ctm_create_member_by_site(self) -> None:
        """Test case for ctm_create_member_by_site

        CTM Update Response
        """
        pass

    async def test_ctm_deallocate(self) -> None:
        """Test case for ctm_deallocate

        CTM Dealocate
        """
        pass

    async def test_ctm_get_custom_messages(self) -> None:
        """Test case for ctm_get_custom_messages

        CTM Custom Messages
        """
        pass

    async def test_ctm_get_member(self) -> None:
        """Test case for ctm_get_member

        CTM Show Response
        """
        pass

    async def test_ctm_get_qitems(self) -> None:
        """Test case for ctm_get_qitems

        CTM Qitems
        """
        pass

    async def test_ctm_get_store(self) -> None:
        """Test case for ctm_get_store

        CTM Stores
        """
        pass

    async def test_ctm_update_member(self) -> None:
        """Test case for ctm_update_member

        CTM Update Response
        """
        pass

    async def test_ctm_update_member_v2(self) -> None:
        """Test case for ctm_update_member_v2

        CTM Show Response
        """
        pass

    async def test_ctm_update_transaction(self) -> None:
        """Test case for ctm_update_transaction

        CTM Transaction Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
