# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.items_api import ItemsApi


class TestItemsApi(unittest.IsolatedAsyncioTestCase):
    """ItemsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ItemsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_add_item_to_set(self) -> None:
        """Test case for add_item_to_set

        Add Item to Set
        """
        pass

    async def test_create_item(self) -> None:
        """Test case for create_item

        Create Item
        """
        pass

    async def test_create_item_set(self) -> None:
        """Test case for create_item_set

        Item Set Create
        """
        pass

    async def test_delete_item(self) -> None:
        """Test case for delete_item

        Delete Item
        """
        pass

    async def test_delete_item_set(self) -> None:
        """Test case for delete_item_set

        Delete an Item Set
        """
        pass

    async def test_get_item(self) -> None:
        """Test case for get_item

        Get Item
        """
        pass

    async def test_get_item_set(self) -> None:
        """Test case for get_item_set

        Get an Item Set
        """
        pass

    async def test_list_item_sets(self) -> None:
        """Test case for list_item_sets

        Item Set Index
        """
        pass

    async def test_list_items(self) -> None:
        """Test case for list_items

        Item Index
        """
        pass

    async def test_list_set_items(self) -> None:
        """Test case for list_set_items

        Item Set Item Index
        """
        pass

    async def test_remove_item_from_set(self) -> None:
        """Test case for remove_item_from_set

        Remove Item from Set
        """
        pass

    async def test_update_item(self) -> None:
        """Test case for update_item

        Update Item
        """
        pass

    async def test_update_item_set(self) -> None:
        """Test case for update_item_set

        Update an Item Set
        """
        pass


if __name__ == '__main__':
    unittest.main()
