# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.offer_pos_offer_codes_api import OfferPOSOfferCodesApi


class TestOfferPOSOfferCodesApi(unittest.IsolatedAsyncioTestCase):
    """OfferPOSOfferCodesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OfferPOSOfferCodesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_pos_code(self) -> None:
        """Test case for create_pos_code

        Create an Offer POS Offer Code
        """
        pass

    async def test_delete_pos_code(self) -> None:
        """Test case for delete_pos_code

        Remove an Offer POS Offer Code
        """
        pass

    async def test_get_offer_pos_code(self) -> None:
        """Test case for get_offer_pos_code

        Get an Offer POS Offer Code
        """
        pass

    async def test_list_pos_codes(self) -> None:
        """Test case for list_pos_codes

        List all Offer POS Offer Codes
        """
        pass

    async def test_update_pos_code(self) -> None:
        """Test case for update_pos_code

        Update an Offer POS Offer Code
        """
        pass


if __name__ == '__main__':
    unittest.main()
