# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.stores_api import StoresApi


class TestStoresApi(unittest.IsolatedAsyncioTestCase):
    """StoresApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = StoresApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_store(self) -> None:
        """Test case for create_store

        Create a Store
        """
        pass

    async def test_delete_store(self) -> None:
        """Test case for delete_store

        Remove a Store
        """
        pass

    async def test_get_store(self) -> None:
        """Test case for get_store

        Retrieve a Store
        """
        pass

    async def test_list_stores(self) -> None:
        """Test case for list_stores

        List all Stores
        """
        pass

    async def test_list_stores_index(self) -> None:
        """Test case for list_stores_index

        List all Stores with Active Offers
        """
        pass

    async def test_update_store(self) -> None:
        """Test case for update_store

        Update a Store
        """
        pass


if __name__ == '__main__':
    unittest.main()
