# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.audiences_api import AudiencesApi


class TestAudiencesApi(unittest.IsolatedAsyncioTestCase):
    """AudiencesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = AudiencesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_audience(self) -> None:
        """Test case for create_audience

        Create an Audience
        """
        pass

    async def test_create_sub_audience(self) -> None:
        """Test case for create_sub_audience

        Create a Sub-Audience
        """
        pass

    async def test_delete_audience(self) -> None:
        """Test case for delete_audience

        Remove an Audience
        """
        pass

    async def test_delete_sub_audience(self) -> None:
        """Test case for delete_sub_audience

        Remove a Sub-Audience
        """
        pass

    async def test_get_audience(self) -> None:
        """Test case for get_audience

        Retrieve an Audience
        """
        pass

    async def test_get_sub_audience(self) -> None:
        """Test case for get_sub_audience

        Retrieve a Sub-Audience
        """
        pass

    async def test_list_audiences(self) -> None:
        """Test case for list_audiences

        List all Audiences
        """
        pass

    async def test_list_sub_audiences(self) -> None:
        """Test case for list_sub_audiences

        List all Sub-Audiences
        """
        pass

    async def test_update_audience(self) -> None:
        """Test case for update_audience

        Update an Audience
        """
        pass

    async def test_update_sub_audience(self) -> None:
        """Test case for update_sub_audience

        Update a Sub-Audience
        """
        pass


if __name__ == '__main__':
    unittest.main()
