# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.offer_states_api import OfferStatesApi


class TestOfferStatesApi(unittest.IsolatedAsyncioTestCase):
    """OfferStatesApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = OfferStatesApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_offer_state(self) -> None:
        """Test case for create_offer_state

        Create Offer State from Query Parameters
        """
        pass

    async def test_get_offer_state(self) -> None:
        """Test case for get_offer_state

        Get Offer State by Offer State ID
        """
        pass

    async def test_issue_offer(self) -> None:
        """Test case for issue_offer

        Issue an Offer to a member (high throughput)
        """
        pass

    async def test_issue_offer_state(self) -> None:
        """Test case for issue_offer_state

        Create Offer State
        """
        pass

    async def test_list_members_offers(self) -> None:
        """Test case for list_members_offers

        Get Offer State by Offer ID
        """
        pass

    async def test_list_offer_states(self) -> None:
        """Test case for list_offer_states

        Get all Offer States
        """
        pass

    async def test_query_offer_states(self) -> None:
        """Test case for query_offer_states

        Get Offer State from Query Parameters
        """
        pass

    async def test_redeem_offer_state(self) -> None:
        """Test case for redeem_offer_state

        Update Offer State - Post
        """
        pass

    async def test_update_offer_state(self) -> None:
        """Test case for update_offer_state

        Update Offer State
        """
        pass

    async def test_void_offer_state(self) -> None:
        """Test case for void_offer_state

        Void Offer State
        """
        pass

    async def test_void_offer_state_by_identifier(self) -> None:
        """Test case for void_offer_state_by_identifier

        Void Offer State by Member Identifier
        """
        pass


if __name__ == '__main__':
    unittest.main()
