# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.campaigns_api import CampaignsApi


class TestCampaignsApi(unittest.IsolatedAsyncioTestCase):
    """CampaignsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CampaignsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_approve_campaign(self) -> None:
        """Test case for approve_campaign

        Set a Campaign's Status
        """
        pass

    async def test_create_campaign(self) -> None:
        """Test case for create_campaign

        Create a Campaign
        """
        pass

    async def test_get_campaign(self) -> None:
        """Test case for get_campaign

        Retrieve a Campaign by Campaign ID
        """
        pass

    async def test_list_campaign_tags(self) -> None:
        """Test case for list_campaign_tags

        Retrieve Campaign Tags
        """
        pass

    async def test_list_campaigns(self) -> None:
        """Test case for list_campaigns

        List all Campaigns
        """
        pass

    async def test_update_campaign(self) -> None:
        """Test case for update_campaign

        Update a Campaign by Campaign ID
        """
        pass


if __name__ == '__main__':
    unittest.main()
