# coding: utf-8

# flake8: noqa

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.3.5"

# Define package exports
__all__ = [
    "AudiencesApi",
    "AuthenticationApi",
    "BIStoreListsApi",
    "CampaignsApi",
    "CredentialsApi",
    "CtmApi",
    "EligibleItemSetsApi",
    "EmailOptInApi",
    "EventNotificationsApi",
    "ImpressionsApi",
    "ItemsApi",
    "MemberPrivacyApi",
    "MembersApi",
    "OfferListsApi",
    "OfferPOSOfferCodesApi",
    "OfferStatesApi",
    "OffersApi",
    "POSOfferCodesApi",
    "StoreListsApi",
    "StoresApi",
    "TemplatesApi",
    "TransactionsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ApiError",
    "AtomicMemberCreateBody",
    "AtomicMemberCreateBodyMember",
    "AtomicMemberCreateBodyMemberCredentialsInner",
    "AtomicMemberCreateBodyMemberCredentialsInnerCredential",
    "AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInner",
    "AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment",
    "AtomicMemberCreateBodyMemberMemberProfile",
    "AtomicMemberResponseBody",
    "AtomicMemberResponseBodyMember",
    "AtomicMemberResponseBodyMemberCredentialsInner",
    "AtomicMemberResponseBodyMemberCredentialsInnerCredential",
    "AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInner",
    "AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment",
    "AtomicMemberResponseBodyMemberMemberProfile",
    "Audience",
    "AudienceData",
    "AudienceIndexBody",
    "AudienceIndexData",
    "Authenticate401Response",
    "BiStoreList",
    "BiStoreListStoreListsInner",
    "Callback",
    "CallbackRequest",
    "CallbackRequestCallback",
    "CallbackResponse",
    "CallbacksIndexBody",
    "CampaignIndexBody",
    "CampaignRequest",
    "CampaignRequestCampaign",
    "CampaignResponse",
    "CampaignResponseCampaign",
    "CampaignTagsResponse",
    "ClarkAndRiggsIndexBody",
    "ClarkAndRiggsProductCreateBody",
    "ClarkAndRiggsProductResponseBody",
    "ClarkAndRiggsProductResponseBodyClarkAndRiggsProduct",
    "CreateAudienceRequest",
    "CreateOfferListRequest",
    "CreateOfferListRequestOfferList",
    "CreateProfileRequest",
    "CreateSubAudienceRequest",
    "CredentialBatchIndexBody",
    "CredentialBatchRequest",
    "CredentialBatchResponseBody",
    "CredentialBatchResponseBodyCredentialBatch",
    "CredentialBatchResponseBodyCredentialBatchCampaign",
    "CredentialBatchResponseBodyCredentialBatchOffer",
    "CredentialCreateRequest",
    "CredentialCreateRequestCredential",
    "CredentialCreateResponse",
    "CredentialCreateResponseCredential",
    "CtmQitemsRequest",
    "CtmRedemptionJobRequest",
    "CtmRedemptionJobRequestItemsInner",
    "CtmRedemptionJobRequestRedeemedOffersInner",
    "CtmRedemptionJobRequestRedeemedOffersInnerQualifyingItemsInner",
    "CtmRedemptionJobRequestSelectedOffersInner",
    "CtmTransactionJobRequest",
    "CtmTransactionShowResponse",
    "CtmTransactionShowResponseAvailibleOffersInner",
    "CtmTransactionShowResponseReusableOffers",
    "CtmTransactionShowResponseTransaction",
    "CtmTransactionShowResponseTransactionAddOffersInner",
    "CtmTransactionShowResponseTransactionAddOffersInnerQualifyingItemsInner",
    "CtmTransactionShowResponseTransactionAvailibleOffersInner",
    "CtmTransactionShowResponseTransactionCredentialsInner",
    "CtmTransactionShowResponseTransactionCredentialsInnerTxCredential",
    "CtmTransactionShowResponseTransactionDisplayMessagesInner",
    "CtmTransactionShowResponseTransactionErrorsInner",
    "CtmTransactionShowResponseTransactionRecieptMessagesInner",
    "EmailOptIn",
    "EmailOptInError",
    "Errors",
    "HealthCheck",
    "Impression",
    "ImpressionAllOfImpression",
    "ImpressionErrorBody",
    "ImpressionIndexBody",
    "ImpressionRequest",
    "ImpressionRequestImpression",
    "ImpressionRequestImpressionAnnotations",
    "IssueOffer201Response",
    "IssueOffer201ResponseOfferState",
    "IssueOfferRequest",
    "IssueOfferRequestOfferState",
    "Item",
    "ItemAllOfItem",
    "ItemIndexBody",
    "ItemRequest",
    "ItemRequestItem",
    "ItemSet",
    "ItemSetAllOfItemSet",
    "ItemSetIndexBody",
    "ItemSetRequest",
    "ItemSetRequestItemSet",
    "Member",
    "MemberAllOfMember",
    "MemberIndexBody",
    "MemberPrivacy",
    "MemberPrivacyCredentialsInner",
    "MemberPrivacyMember",
    "MemberProfile",
    "MemberProfileData",
    "MemberRequest",
    "MemberRequestMember",
    "Offer",
    "OfferAllOfOffer",
    "OfferEligibleItemSet",
    "OfferEligibleItemSetAllOfEligibleItemSet",
    "OfferEligibleItemSetRequest",
    "OfferEligibleItemSetRequestEligibleItemSet",
    "OfferEligibleItemsSetIndex",
    "OfferIndexBody",
    "OfferList",
    "OfferListData",
    "OfferListsIndexBody",
    "OfferPosOfferCode",
    "OfferPosOfferCodeAllOfOfferPosOfferCode",
    "OfferPosOfferCodeIndex",
    "OfferPosOfferCodeRequest",
    "OfferPosOfferCodeRequestOfferPosOfferCode",
    "OfferRequest",
    "OfferRequestOffer",
    "OfferRequestOfferEligibility",
    "OfferRequestOfferFormatting",
    "OfferRequestOfferFormattingEligibleStoreMap",
    "OfferState",
    "OfferStateAllOfOfferState",
    "OfferStateError",
    "OfferStateIndexBody",
    "OfferStateRequest",
    "OfferStateRequestOfferState",
    "OfferStateUpdate",
    "OfferStateUpdateOfferState",
    "PageResponseBody",
    "PosOfferCode",
    "PosOfferCodeAllOfPosOfferCode",
    "PosOfferCodeIndexBody",
    "Store",
    "StoreAllOfStore",
    "StoreAllOfStoreLocation",
    "StoreIndexBody",
    "StoreList",
    "StoreListAllOfStoreList",
    "StoreListIndexBody",
    "StoreListRequest",
    "StoreListRequestStoreList",
    "StoreRequest",
    "StoreRequestStore",
    "StoreRequestStoreContacts",
    "StoreRequestStoreContactsPrimary",
    "StoreRequestStoreLocation",
    "SubAudience",
    "SubAudienceData",
    "SubAudienceIndexBody",
    "SubAudienceIndexData",
    "Subscription",
    "SubscriptionRequest",
    "SubscriptionRequestSubscription",
    "SubscriptionResponse",
    "SubscriptionsIndexBody",
    "Template",
    "Template2",
    "TemplateTemplatesInner",
    "TransactionAppliedCredential",
    "TransactionCampaign",
    "TransactionCampaignOffer",
    "TransactionItem",
    "TransactionRedemption",
    "TransactionResponse",
    "TransactionResponseTransaction",
    "TransactionTotals",
]

# import apis into sdk package
from sparkfly.api.audiences_api import AudiencesApi as AudiencesApi
from sparkfly.api.authentication_api import AuthenticationApi as AuthenticationApi
from sparkfly.api.bi_store_lists_api import BIStoreListsApi as BIStoreListsApi
from sparkfly.api.campaigns_api import CampaignsApi as CampaignsApi
from sparkfly.api.credentials_api import CredentialsApi as CredentialsApi
from sparkfly.api.ctm_api import CtmApi as CtmApi
from sparkfly.api.eligible_item_sets_api import EligibleItemSetsApi as EligibleItemSetsApi
from sparkfly.api.email_opt_in_api import EmailOptInApi as EmailOptInApi
from sparkfly.api.event_notifications_api import EventNotificationsApi as EventNotificationsApi
from sparkfly.api.impressions_api import ImpressionsApi as ImpressionsApi
from sparkfly.api.items_api import ItemsApi as ItemsApi
from sparkfly.api.member_privacy_api import MemberPrivacyApi as MemberPrivacyApi
from sparkfly.api.members_api import MembersApi as MembersApi
from sparkfly.api.offer_lists_api import OfferListsApi as OfferListsApi
from sparkfly.api.offer_pos_offer_codes_api import OfferPOSOfferCodesApi as OfferPOSOfferCodesApi
from sparkfly.api.offer_states_api import OfferStatesApi as OfferStatesApi
from sparkfly.api.offers_api import OffersApi as OffersApi
from sparkfly.api.pos_offer_codes_api import POSOfferCodesApi as POSOfferCodesApi
from sparkfly.api.store_lists_api import StoreListsApi as StoreListsApi
from sparkfly.api.stores_api import StoresApi as StoresApi
from sparkfly.api.templates_api import TemplatesApi as TemplatesApi
from sparkfly.api.transactions_api import TransactionsApi as TransactionsApi

# import ApiClient
from sparkfly.api_response import ApiResponse as ApiResponse
from sparkfly.api_client import ApiClient as ApiClient
from sparkfly.configuration import Configuration as Configuration
from sparkfly.exceptions import OpenApiException as OpenApiException
from sparkfly.exceptions import ApiTypeError as ApiTypeError
from sparkfly.exceptions import ApiValueError as ApiValueError
from sparkfly.exceptions import ApiKeyError as ApiKeyError
from sparkfly.exceptions import ApiAttributeError as ApiAttributeError
from sparkfly.exceptions import ApiException as ApiException

# import models into sdk package
from sparkfly.models.api_error import ApiError as ApiError
from sparkfly.models.atomic_member_create_body import AtomicMemberCreateBody as AtomicMemberCreateBody
from sparkfly.models.atomic_member_create_body_member import AtomicMemberCreateBodyMember as AtomicMemberCreateBodyMember
from sparkfly.models.atomic_member_create_body_member_credentials_inner import AtomicMemberCreateBodyMemberCredentialsInner as AtomicMemberCreateBodyMemberCredentialsInner
from sparkfly.models.atomic_member_create_body_member_credentials_inner_credential import AtomicMemberCreateBodyMemberCredentialsInnerCredential as AtomicMemberCreateBodyMemberCredentialsInnerCredential
from sparkfly.models.atomic_member_create_body_member_loyalty_enrollments_inner import AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInner as AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInner
from sparkfly.models.atomic_member_create_body_member_loyalty_enrollments_inner_loyalty_enrollment import AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment as AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment
from sparkfly.models.atomic_member_create_body_member_member_profile import AtomicMemberCreateBodyMemberMemberProfile as AtomicMemberCreateBodyMemberMemberProfile
from sparkfly.models.atomic_member_response_body import AtomicMemberResponseBody as AtomicMemberResponseBody
from sparkfly.models.atomic_member_response_body_member import AtomicMemberResponseBodyMember as AtomicMemberResponseBodyMember
from sparkfly.models.atomic_member_response_body_member_credentials_inner import AtomicMemberResponseBodyMemberCredentialsInner as AtomicMemberResponseBodyMemberCredentialsInner
from sparkfly.models.atomic_member_response_body_member_credentials_inner_credential import AtomicMemberResponseBodyMemberCredentialsInnerCredential as AtomicMemberResponseBodyMemberCredentialsInnerCredential
from sparkfly.models.atomic_member_response_body_member_loyalty_enrollments_inner import AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInner as AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInner
from sparkfly.models.atomic_member_response_body_member_loyalty_enrollments_inner_loyalty_enrollment import AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment as AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment
from sparkfly.models.atomic_member_response_body_member_member_profile import AtomicMemberResponseBodyMemberMemberProfile as AtomicMemberResponseBodyMemberMemberProfile
from sparkfly.models.audience import Audience as Audience
from sparkfly.models.audience_data import AudienceData as AudienceData
from sparkfly.models.audience_index_body import AudienceIndexBody as AudienceIndexBody
from sparkfly.models.audience_index_data import AudienceIndexData as AudienceIndexData
from sparkfly.models.authenticate401_response import Authenticate401Response as Authenticate401Response
from sparkfly.models.bi_store_list import BiStoreList as BiStoreList
from sparkfly.models.bi_store_list_store_lists_inner import BiStoreListStoreListsInner as BiStoreListStoreListsInner
from sparkfly.models.callback import Callback as Callback
from sparkfly.models.callback_request import CallbackRequest as CallbackRequest
from sparkfly.models.callback_request_callback import CallbackRequestCallback as CallbackRequestCallback
from sparkfly.models.callback_response import CallbackResponse as CallbackResponse
from sparkfly.models.callbacks_index_body import CallbacksIndexBody as CallbacksIndexBody
from sparkfly.models.campaign_index_body import CampaignIndexBody as CampaignIndexBody
from sparkfly.models.campaign_request import CampaignRequest as CampaignRequest
from sparkfly.models.campaign_request_campaign import CampaignRequestCampaign as CampaignRequestCampaign
from sparkfly.models.campaign_response import CampaignResponse as CampaignResponse
from sparkfly.models.campaign_response_campaign import CampaignResponseCampaign as CampaignResponseCampaign
from sparkfly.models.campaign_tags_response import CampaignTagsResponse as CampaignTagsResponse
from sparkfly.models.clark_and_riggs_index_body import ClarkAndRiggsIndexBody as ClarkAndRiggsIndexBody
from sparkfly.models.clark_and_riggs_product_create_body import ClarkAndRiggsProductCreateBody as ClarkAndRiggsProductCreateBody
from sparkfly.models.clark_and_riggs_product_response_body import ClarkAndRiggsProductResponseBody as ClarkAndRiggsProductResponseBody
from sparkfly.models.clark_and_riggs_product_response_body_clark_and_riggs_product import ClarkAndRiggsProductResponseBodyClarkAndRiggsProduct as ClarkAndRiggsProductResponseBodyClarkAndRiggsProduct
from sparkfly.models.create_audience_request import CreateAudienceRequest as CreateAudienceRequest
from sparkfly.models.create_offer_list_request import CreateOfferListRequest as CreateOfferListRequest
from sparkfly.models.create_offer_list_request_offer_list import CreateOfferListRequestOfferList as CreateOfferListRequestOfferList
from sparkfly.models.create_profile_request import CreateProfileRequest as CreateProfileRequest
from sparkfly.models.create_sub_audience_request import CreateSubAudienceRequest as CreateSubAudienceRequest
from sparkfly.models.credential_batch_index_body import CredentialBatchIndexBody as CredentialBatchIndexBody
from sparkfly.models.credential_batch_request import CredentialBatchRequest as CredentialBatchRequest
from sparkfly.models.credential_batch_response_body import CredentialBatchResponseBody as CredentialBatchResponseBody
from sparkfly.models.credential_batch_response_body_credential_batch import CredentialBatchResponseBodyCredentialBatch as CredentialBatchResponseBodyCredentialBatch
from sparkfly.models.credential_batch_response_body_credential_batch_campaign import CredentialBatchResponseBodyCredentialBatchCampaign as CredentialBatchResponseBodyCredentialBatchCampaign
from sparkfly.models.credential_batch_response_body_credential_batch_offer import CredentialBatchResponseBodyCredentialBatchOffer as CredentialBatchResponseBodyCredentialBatchOffer
from sparkfly.models.credential_create_request import CredentialCreateRequest as CredentialCreateRequest
from sparkfly.models.credential_create_request_credential import CredentialCreateRequestCredential as CredentialCreateRequestCredential
from sparkfly.models.credential_create_response import CredentialCreateResponse as CredentialCreateResponse
from sparkfly.models.credential_create_response_credential import CredentialCreateResponseCredential as CredentialCreateResponseCredential
from sparkfly.models.ctm_qitems_request import CtmQitemsRequest as CtmQitemsRequest
from sparkfly.models.ctm_redemption_job_request import CtmRedemptionJobRequest as CtmRedemptionJobRequest
from sparkfly.models.ctm_redemption_job_request_items_inner import CtmRedemptionJobRequestItemsInner as CtmRedemptionJobRequestItemsInner
from sparkfly.models.ctm_redemption_job_request_redeemed_offers_inner import CtmRedemptionJobRequestRedeemedOffersInner as CtmRedemptionJobRequestRedeemedOffersInner
from sparkfly.models.ctm_redemption_job_request_redeemed_offers_inner_qualifying_items_inner import CtmRedemptionJobRequestRedeemedOffersInnerQualifyingItemsInner as CtmRedemptionJobRequestRedeemedOffersInnerQualifyingItemsInner
from sparkfly.models.ctm_redemption_job_request_selected_offers_inner import CtmRedemptionJobRequestSelectedOffersInner as CtmRedemptionJobRequestSelectedOffersInner
from sparkfly.models.ctm_transaction_job_request import CtmTransactionJobRequest as CtmTransactionJobRequest
from sparkfly.models.ctm_transaction_show_response import CtmTransactionShowResponse as CtmTransactionShowResponse
from sparkfly.models.ctm_transaction_show_response_availible_offers_inner import CtmTransactionShowResponseAvailibleOffersInner as CtmTransactionShowResponseAvailibleOffersInner
from sparkfly.models.ctm_transaction_show_response_reusable_offers import CtmTransactionShowResponseReusableOffers as CtmTransactionShowResponseReusableOffers
from sparkfly.models.ctm_transaction_show_response_transaction import CtmTransactionShowResponseTransaction as CtmTransactionShowResponseTransaction
from sparkfly.models.ctm_transaction_show_response_transaction_add_offers_inner import CtmTransactionShowResponseTransactionAddOffersInner as CtmTransactionShowResponseTransactionAddOffersInner
from sparkfly.models.ctm_transaction_show_response_transaction_add_offers_inner_qualifying_items_inner import CtmTransactionShowResponseTransactionAddOffersInnerQualifyingItemsInner as CtmTransactionShowResponseTransactionAddOffersInnerQualifyingItemsInner
from sparkfly.models.ctm_transaction_show_response_transaction_availible_offers_inner import CtmTransactionShowResponseTransactionAvailibleOffersInner as CtmTransactionShowResponseTransactionAvailibleOffersInner
from sparkfly.models.ctm_transaction_show_response_transaction_credentials_inner import CtmTransactionShowResponseTransactionCredentialsInner as CtmTransactionShowResponseTransactionCredentialsInner
from sparkfly.models.ctm_transaction_show_response_transaction_credentials_inner_tx_credential import CtmTransactionShowResponseTransactionCredentialsInnerTxCredential as CtmTransactionShowResponseTransactionCredentialsInnerTxCredential
from sparkfly.models.ctm_transaction_show_response_transaction_display_messages_inner import CtmTransactionShowResponseTransactionDisplayMessagesInner as CtmTransactionShowResponseTransactionDisplayMessagesInner
from sparkfly.models.ctm_transaction_show_response_transaction_errors_inner import CtmTransactionShowResponseTransactionErrorsInner as CtmTransactionShowResponseTransactionErrorsInner
from sparkfly.models.ctm_transaction_show_response_transaction_reciept_messages_inner import CtmTransactionShowResponseTransactionRecieptMessagesInner as CtmTransactionShowResponseTransactionRecieptMessagesInner
from sparkfly.models.email_opt_in import EmailOptIn as EmailOptIn
from sparkfly.models.email_opt_in_error import EmailOptInError as EmailOptInError
from sparkfly.models.errors import Errors as Errors
from sparkfly.models.health_check import HealthCheck as HealthCheck
from sparkfly.models.impression import Impression as Impression
from sparkfly.models.impression_all_of_impression import ImpressionAllOfImpression as ImpressionAllOfImpression
from sparkfly.models.impression_error_body import ImpressionErrorBody as ImpressionErrorBody
from sparkfly.models.impression_index_body import ImpressionIndexBody as ImpressionIndexBody
from sparkfly.models.impression_request import ImpressionRequest as ImpressionRequest
from sparkfly.models.impression_request_impression import ImpressionRequestImpression as ImpressionRequestImpression
from sparkfly.models.impression_request_impression_annotations import ImpressionRequestImpressionAnnotations as ImpressionRequestImpressionAnnotations
from sparkfly.models.issue_offer201_response import IssueOffer201Response as IssueOffer201Response
from sparkfly.models.issue_offer201_response_offer_state import IssueOffer201ResponseOfferState as IssueOffer201ResponseOfferState
from sparkfly.models.issue_offer_request import IssueOfferRequest as IssueOfferRequest
from sparkfly.models.issue_offer_request_offer_state import IssueOfferRequestOfferState as IssueOfferRequestOfferState
from sparkfly.models.item import Item as Item
from sparkfly.models.item_all_of_item import ItemAllOfItem as ItemAllOfItem
from sparkfly.models.item_index_body import ItemIndexBody as ItemIndexBody
from sparkfly.models.item_request import ItemRequest as ItemRequest
from sparkfly.models.item_request_item import ItemRequestItem as ItemRequestItem
from sparkfly.models.item_set import ItemSet as ItemSet
from sparkfly.models.item_set_all_of_item_set import ItemSetAllOfItemSet as ItemSetAllOfItemSet
from sparkfly.models.item_set_index_body import ItemSetIndexBody as ItemSetIndexBody
from sparkfly.models.item_set_request import ItemSetRequest as ItemSetRequest
from sparkfly.models.item_set_request_item_set import ItemSetRequestItemSet as ItemSetRequestItemSet
from sparkfly.models.member import Member as Member
from sparkfly.models.member_all_of_member import MemberAllOfMember as MemberAllOfMember
from sparkfly.models.member_index_body import MemberIndexBody as MemberIndexBody
from sparkfly.models.member_privacy import MemberPrivacy as MemberPrivacy
from sparkfly.models.member_privacy_credentials_inner import MemberPrivacyCredentialsInner as MemberPrivacyCredentialsInner
from sparkfly.models.member_privacy_member import MemberPrivacyMember as MemberPrivacyMember
from sparkfly.models.member_profile import MemberProfile as MemberProfile
from sparkfly.models.member_profile_data import MemberProfileData as MemberProfileData
from sparkfly.models.member_request import MemberRequest as MemberRequest
from sparkfly.models.member_request_member import MemberRequestMember as MemberRequestMember
from sparkfly.models.offer import Offer as Offer
from sparkfly.models.offer_all_of_offer import OfferAllOfOffer as OfferAllOfOffer
from sparkfly.models.offer_eligible_item_set import OfferEligibleItemSet as OfferEligibleItemSet
from sparkfly.models.offer_eligible_item_set_all_of_eligible_item_set import OfferEligibleItemSetAllOfEligibleItemSet as OfferEligibleItemSetAllOfEligibleItemSet
from sparkfly.models.offer_eligible_item_set_request import OfferEligibleItemSetRequest as OfferEligibleItemSetRequest
from sparkfly.models.offer_eligible_item_set_request_eligible_item_set import OfferEligibleItemSetRequestEligibleItemSet as OfferEligibleItemSetRequestEligibleItemSet
from sparkfly.models.offer_eligible_items_set_index import OfferEligibleItemsSetIndex as OfferEligibleItemsSetIndex
from sparkfly.models.offer_index_body import OfferIndexBody as OfferIndexBody
from sparkfly.models.offer_list import OfferList as OfferList
from sparkfly.models.offer_list_data import OfferListData as OfferListData
from sparkfly.models.offer_lists_index_body import OfferListsIndexBody as OfferListsIndexBody
from sparkfly.models.offer_pos_offer_code import OfferPosOfferCode as OfferPosOfferCode
from sparkfly.models.offer_pos_offer_code_all_of_offer_pos_offer_code import OfferPosOfferCodeAllOfOfferPosOfferCode as OfferPosOfferCodeAllOfOfferPosOfferCode
from sparkfly.models.offer_pos_offer_code_index import OfferPosOfferCodeIndex as OfferPosOfferCodeIndex
from sparkfly.models.offer_pos_offer_code_request import OfferPosOfferCodeRequest as OfferPosOfferCodeRequest
from sparkfly.models.offer_pos_offer_code_request_offer_pos_offer_code import OfferPosOfferCodeRequestOfferPosOfferCode as OfferPosOfferCodeRequestOfferPosOfferCode
from sparkfly.models.offer_request import OfferRequest as OfferRequest
from sparkfly.models.offer_request_offer import OfferRequestOffer as OfferRequestOffer
from sparkfly.models.offer_request_offer_eligibility import OfferRequestOfferEligibility as OfferRequestOfferEligibility
from sparkfly.models.offer_request_offer_formatting import OfferRequestOfferFormatting as OfferRequestOfferFormatting
from sparkfly.models.offer_request_offer_formatting_eligible_store_map import OfferRequestOfferFormattingEligibleStoreMap as OfferRequestOfferFormattingEligibleStoreMap
from sparkfly.models.offer_state import OfferState as OfferState
from sparkfly.models.offer_state_all_of_offer_state import OfferStateAllOfOfferState as OfferStateAllOfOfferState
from sparkfly.models.offer_state_error import OfferStateError as OfferStateError
from sparkfly.models.offer_state_index_body import OfferStateIndexBody as OfferStateIndexBody
from sparkfly.models.offer_state_request import OfferStateRequest as OfferStateRequest
from sparkfly.models.offer_state_request_offer_state import OfferStateRequestOfferState as OfferStateRequestOfferState
from sparkfly.models.offer_state_update import OfferStateUpdate as OfferStateUpdate
from sparkfly.models.offer_state_update_offer_state import OfferStateUpdateOfferState as OfferStateUpdateOfferState
from sparkfly.models.page_response_body import PageResponseBody as PageResponseBody
from sparkfly.models.pos_offer_code import PosOfferCode as PosOfferCode
from sparkfly.models.pos_offer_code_all_of_pos_offer_code import PosOfferCodeAllOfPosOfferCode as PosOfferCodeAllOfPosOfferCode
from sparkfly.models.pos_offer_code_index_body import PosOfferCodeIndexBody as PosOfferCodeIndexBody
from sparkfly.models.store import Store as Store
from sparkfly.models.store_all_of_store import StoreAllOfStore as StoreAllOfStore
from sparkfly.models.store_all_of_store_location import StoreAllOfStoreLocation as StoreAllOfStoreLocation
from sparkfly.models.store_index_body import StoreIndexBody as StoreIndexBody
from sparkfly.models.store_list import StoreList as StoreList
from sparkfly.models.store_list_all_of_store_list import StoreListAllOfStoreList as StoreListAllOfStoreList
from sparkfly.models.store_list_index_body import StoreListIndexBody as StoreListIndexBody
from sparkfly.models.store_list_request import StoreListRequest as StoreListRequest
from sparkfly.models.store_list_request_store_list import StoreListRequestStoreList as StoreListRequestStoreList
from sparkfly.models.store_request import StoreRequest as StoreRequest
from sparkfly.models.store_request_store import StoreRequestStore as StoreRequestStore
from sparkfly.models.store_request_store_contacts import StoreRequestStoreContacts as StoreRequestStoreContacts
from sparkfly.models.store_request_store_contacts_primary import StoreRequestStoreContactsPrimary as StoreRequestStoreContactsPrimary
from sparkfly.models.store_request_store_location import StoreRequestStoreLocation as StoreRequestStoreLocation
from sparkfly.models.sub_audience import SubAudience as SubAudience
from sparkfly.models.sub_audience_data import SubAudienceData as SubAudienceData
from sparkfly.models.sub_audience_index_body import SubAudienceIndexBody as SubAudienceIndexBody
from sparkfly.models.sub_audience_index_data import SubAudienceIndexData as SubAudienceIndexData
from sparkfly.models.subscription import Subscription as Subscription
from sparkfly.models.subscription_request import SubscriptionRequest as SubscriptionRequest
from sparkfly.models.subscription_request_subscription import SubscriptionRequestSubscription as SubscriptionRequestSubscription
from sparkfly.models.subscription_response import SubscriptionResponse as SubscriptionResponse
from sparkfly.models.subscriptions_index_body import SubscriptionsIndexBody as SubscriptionsIndexBody
from sparkfly.models.template import Template as Template
from sparkfly.models.template2 import Template2 as Template2
from sparkfly.models.template_templates_inner import TemplateTemplatesInner as TemplateTemplatesInner
from sparkfly.models.transaction_applied_credential import TransactionAppliedCredential as TransactionAppliedCredential
from sparkfly.models.transaction_campaign import TransactionCampaign as TransactionCampaign
from sparkfly.models.transaction_campaign_offer import TransactionCampaignOffer as TransactionCampaignOffer
from sparkfly.models.transaction_item import TransactionItem as TransactionItem
from sparkfly.models.transaction_redemption import TransactionRedemption as TransactionRedemption
from sparkfly.models.transaction_response import TransactionResponse as TransactionResponse
from sparkfly.models.transaction_response_transaction import TransactionResponseTransaction as TransactionResponseTransaction
from sparkfly.models.transaction_totals import TransactionTotals as TransactionTotals
