# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.member_privacy_api import MemberPrivacyApi


class TestMemberPrivacyApi(unittest.IsolatedAsyncioTestCase):
    """MemberPrivacyApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = MemberPrivacyApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_export_member_privacy(self) -> None:
        """Test case for export_member_privacy

        Exports Data Associated with a Member
        """
        pass

    async def test_request_member_deletion(self) -> None:
        """Test case for request_member_deletion

        Creates a Deletion Request for a Member
        """
        pass


if __name__ == '__main__':
    unittest.main()
