# coding: utf-8

# flake8: noqa
"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from sparkfly.models.api_error import ApiError
from sparkfly.models.atomic_member_create_body import AtomicMemberCreateBody
from sparkfly.models.atomic_member_create_body_member import AtomicMemberCreateBodyMember
from sparkfly.models.atomic_member_create_body_member_credentials_inner import AtomicMemberCreateBodyMemberCredentialsInner
from sparkfly.models.atomic_member_create_body_member_credentials_inner_credential import AtomicMemberCreateBodyMemberCredentialsInnerCredential
from sparkfly.models.atomic_member_create_body_member_loyalty_enrollments_inner import AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInner
from sparkfly.models.atomic_member_create_body_member_loyalty_enrollments_inner_loyalty_enrollment import AtomicMemberCreateBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment
from sparkfly.models.atomic_member_create_body_member_member_profile import AtomicMemberCreateBodyMemberMemberProfile
from sparkfly.models.atomic_member_response_body import AtomicMemberResponseBody
from sparkfly.models.atomic_member_response_body_member import AtomicMemberResponseBodyMember
from sparkfly.models.atomic_member_response_body_member_credentials_inner import AtomicMemberResponseBodyMemberCredentialsInner
from sparkfly.models.atomic_member_response_body_member_credentials_inner_credential import AtomicMemberResponseBodyMemberCredentialsInnerCredential
from sparkfly.models.atomic_member_response_body_member_loyalty_enrollments_inner import AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInner
from sparkfly.models.atomic_member_response_body_member_loyalty_enrollments_inner_loyalty_enrollment import AtomicMemberResponseBodyMemberLoyaltyEnrollmentsInnerLoyaltyEnrollment
from sparkfly.models.atomic_member_response_body_member_member_profile import AtomicMemberResponseBodyMemberMemberProfile
from sparkfly.models.audience import Audience
from sparkfly.models.audience_data import AudienceData
from sparkfly.models.audience_index_body import AudienceIndexBody
from sparkfly.models.audience_index_data import AudienceIndexData
from sparkfly.models.authenticate401_response import Authenticate401Response
from sparkfly.models.bi_store_list import BiStoreList
from sparkfly.models.bi_store_list_store_lists_inner import BiStoreListStoreListsInner
from sparkfly.models.callback import Callback
from sparkfly.models.callback_request import CallbackRequest
from sparkfly.models.callback_request_callback import CallbackRequestCallback
from sparkfly.models.callback_response import CallbackResponse
from sparkfly.models.callbacks_index_body import CallbacksIndexBody
from sparkfly.models.campaign_index_body import CampaignIndexBody
from sparkfly.models.campaign_request import CampaignRequest
from sparkfly.models.campaign_request_campaign import CampaignRequestCampaign
from sparkfly.models.campaign_response import CampaignResponse
from sparkfly.models.campaign_response_campaign import CampaignResponseCampaign
from sparkfly.models.campaign_tags_response import CampaignTagsResponse
from sparkfly.models.clark_and_riggs_index_body import ClarkAndRiggsIndexBody
from sparkfly.models.clark_and_riggs_product_create_body import ClarkAndRiggsProductCreateBody
from sparkfly.models.clark_and_riggs_product_response_body import ClarkAndRiggsProductResponseBody
from sparkfly.models.clark_and_riggs_product_response_body_clark_and_riggs_product import ClarkAndRiggsProductResponseBodyClarkAndRiggsProduct
from sparkfly.models.create_audience_request import CreateAudienceRequest
from sparkfly.models.create_offer_list_request import CreateOfferListRequest
from sparkfly.models.create_offer_list_request_offer_list import CreateOfferListRequestOfferList
from sparkfly.models.create_profile_request import CreateProfileRequest
from sparkfly.models.create_sub_audience_request import CreateSubAudienceRequest
from sparkfly.models.credential_batch_index_body import CredentialBatchIndexBody
from sparkfly.models.credential_batch_request import CredentialBatchRequest
from sparkfly.models.credential_batch_response_body import CredentialBatchResponseBody
from sparkfly.models.credential_batch_response_body_credential_batch import CredentialBatchResponseBodyCredentialBatch
from sparkfly.models.credential_batch_response_body_credential_batch_campaign import CredentialBatchResponseBodyCredentialBatchCampaign
from sparkfly.models.credential_batch_response_body_credential_batch_offer import CredentialBatchResponseBodyCredentialBatchOffer
from sparkfly.models.credential_create_request import CredentialCreateRequest
from sparkfly.models.credential_create_request_credential import CredentialCreateRequestCredential
from sparkfly.models.credential_create_response import CredentialCreateResponse
from sparkfly.models.credential_create_response_credential import CredentialCreateResponseCredential
from sparkfly.models.ctm_qitems_request import CtmQitemsRequest
from sparkfly.models.ctm_redemption_job_request import CtmRedemptionJobRequest
from sparkfly.models.ctm_redemption_job_request_items_inner import CtmRedemptionJobRequestItemsInner
from sparkfly.models.ctm_redemption_job_request_redeemed_offers_inner import CtmRedemptionJobRequestRedeemedOffersInner
from sparkfly.models.ctm_redemption_job_request_redeemed_offers_inner_qualifying_items_inner import CtmRedemptionJobRequestRedeemedOffersInnerQualifyingItemsInner
from sparkfly.models.ctm_redemption_job_request_selected_offers_inner import CtmRedemptionJobRequestSelectedOffersInner
from sparkfly.models.ctm_transaction_job_request import CtmTransactionJobRequest
from sparkfly.models.ctm_transaction_show_response import CtmTransactionShowResponse
from sparkfly.models.ctm_transaction_show_response_availible_offers_inner import CtmTransactionShowResponseAvailibleOffersInner
from sparkfly.models.ctm_transaction_show_response_reusable_offers import CtmTransactionShowResponseReusableOffers
from sparkfly.models.ctm_transaction_show_response_transaction import CtmTransactionShowResponseTransaction
from sparkfly.models.ctm_transaction_show_response_transaction_add_offers_inner import CtmTransactionShowResponseTransactionAddOffersInner
from sparkfly.models.ctm_transaction_show_response_transaction_add_offers_inner_qualifying_items_inner import CtmTransactionShowResponseTransactionAddOffersInnerQualifyingItemsInner
from sparkfly.models.ctm_transaction_show_response_transaction_availible_offers_inner import CtmTransactionShowResponseTransactionAvailibleOffersInner
from sparkfly.models.ctm_transaction_show_response_transaction_credentials_inner import CtmTransactionShowResponseTransactionCredentialsInner
from sparkfly.models.ctm_transaction_show_response_transaction_credentials_inner_tx_credential import CtmTransactionShowResponseTransactionCredentialsInnerTxCredential
from sparkfly.models.ctm_transaction_show_response_transaction_display_messages_inner import CtmTransactionShowResponseTransactionDisplayMessagesInner
from sparkfly.models.ctm_transaction_show_response_transaction_errors_inner import CtmTransactionShowResponseTransactionErrorsInner
from sparkfly.models.ctm_transaction_show_response_transaction_reciept_messages_inner import CtmTransactionShowResponseTransactionRecieptMessagesInner
from sparkfly.models.email_opt_in import EmailOptIn
from sparkfly.models.email_opt_in_error import EmailOptInError
from sparkfly.models.errors import Errors
from sparkfly.models.health_check import HealthCheck
from sparkfly.models.impression import Impression
from sparkfly.models.impression_all_of_impression import ImpressionAllOfImpression
from sparkfly.models.impression_error_body import ImpressionErrorBody
from sparkfly.models.impression_index_body import ImpressionIndexBody
from sparkfly.models.impression_request import ImpressionRequest
from sparkfly.models.impression_request_impression import ImpressionRequestImpression
from sparkfly.models.impression_request_impression_annotations import ImpressionRequestImpressionAnnotations
from sparkfly.models.issue_offer201_response import IssueOffer201Response
from sparkfly.models.issue_offer201_response_offer_state import IssueOffer201ResponseOfferState
from sparkfly.models.issue_offer_request import IssueOfferRequest
from sparkfly.models.issue_offer_request_offer_state import IssueOfferRequestOfferState
from sparkfly.models.item import Item
from sparkfly.models.item_all_of_item import ItemAllOfItem
from sparkfly.models.item_index_body import ItemIndexBody
from sparkfly.models.item_request import ItemRequest
from sparkfly.models.item_request_item import ItemRequestItem
from sparkfly.models.item_set import ItemSet
from sparkfly.models.item_set_all_of_item_set import ItemSetAllOfItemSet
from sparkfly.models.item_set_index_body import ItemSetIndexBody
from sparkfly.models.item_set_request import ItemSetRequest
from sparkfly.models.item_set_request_item_set import ItemSetRequestItemSet
from sparkfly.models.member import Member
from sparkfly.models.member_all_of_member import MemberAllOfMember
from sparkfly.models.member_index_body import MemberIndexBody
from sparkfly.models.member_privacy import MemberPrivacy
from sparkfly.models.member_privacy_credentials_inner import MemberPrivacyCredentialsInner
from sparkfly.models.member_privacy_member import MemberPrivacyMember
from sparkfly.models.member_profile import MemberProfile
from sparkfly.models.member_profile_data import MemberProfileData
from sparkfly.models.member_request import MemberRequest
from sparkfly.models.member_request_member import MemberRequestMember
from sparkfly.models.offer import Offer
from sparkfly.models.offer_all_of_offer import OfferAllOfOffer
from sparkfly.models.offer_eligible_item_set import OfferEligibleItemSet
from sparkfly.models.offer_eligible_item_set_all_of_eligible_item_set import OfferEligibleItemSetAllOfEligibleItemSet
from sparkfly.models.offer_eligible_item_set_request import OfferEligibleItemSetRequest
from sparkfly.models.offer_eligible_item_set_request_eligible_item_set import OfferEligibleItemSetRequestEligibleItemSet
from sparkfly.models.offer_eligible_items_set_index import OfferEligibleItemsSetIndex
from sparkfly.models.offer_index_body import OfferIndexBody
from sparkfly.models.offer_list import OfferList
from sparkfly.models.offer_list_data import OfferListData
from sparkfly.models.offer_lists_index_body import OfferListsIndexBody
from sparkfly.models.offer_pos_offer_code import OfferPosOfferCode
from sparkfly.models.offer_pos_offer_code_all_of_offer_pos_offer_code import OfferPosOfferCodeAllOfOfferPosOfferCode
from sparkfly.models.offer_pos_offer_code_index import OfferPosOfferCodeIndex
from sparkfly.models.offer_pos_offer_code_request import OfferPosOfferCodeRequest
from sparkfly.models.offer_pos_offer_code_request_offer_pos_offer_code import OfferPosOfferCodeRequestOfferPosOfferCode
from sparkfly.models.offer_request import OfferRequest
from sparkfly.models.offer_request_offer import OfferRequestOffer
from sparkfly.models.offer_request_offer_eligibility import OfferRequestOfferEligibility
from sparkfly.models.offer_request_offer_formatting import OfferRequestOfferFormatting
from sparkfly.models.offer_request_offer_formatting_eligible_store_map import OfferRequestOfferFormattingEligibleStoreMap
from sparkfly.models.offer_state import OfferState
from sparkfly.models.offer_state_all_of_offer_state import OfferStateAllOfOfferState
from sparkfly.models.offer_state_error import OfferStateError
from sparkfly.models.offer_state_index_body import OfferStateIndexBody
from sparkfly.models.offer_state_request import OfferStateRequest
from sparkfly.models.offer_state_request_offer_state import OfferStateRequestOfferState
from sparkfly.models.offer_state_update import OfferStateUpdate
from sparkfly.models.offer_state_update_offer_state import OfferStateUpdateOfferState
from sparkfly.models.page_response_body import PageResponseBody
from sparkfly.models.pos_offer_code import PosOfferCode
from sparkfly.models.pos_offer_code_all_of_pos_offer_code import PosOfferCodeAllOfPosOfferCode
from sparkfly.models.pos_offer_code_index_body import PosOfferCodeIndexBody
from sparkfly.models.store import Store
from sparkfly.models.store_all_of_store import StoreAllOfStore
from sparkfly.models.store_all_of_store_location import StoreAllOfStoreLocation
from sparkfly.models.store_index_body import StoreIndexBody
from sparkfly.models.store_list import StoreList
from sparkfly.models.store_list_all_of_store_list import StoreListAllOfStoreList
from sparkfly.models.store_list_index_body import StoreListIndexBody
from sparkfly.models.store_list_request import StoreListRequest
from sparkfly.models.store_list_request_store_list import StoreListRequestStoreList
from sparkfly.models.store_request import StoreRequest
from sparkfly.models.store_request_store import StoreRequestStore
from sparkfly.models.store_request_store_contacts import StoreRequestStoreContacts
from sparkfly.models.store_request_store_contacts_primary import StoreRequestStoreContactsPrimary
from sparkfly.models.store_request_store_location import StoreRequestStoreLocation
from sparkfly.models.sub_audience import SubAudience
from sparkfly.models.sub_audience_data import SubAudienceData
from sparkfly.models.sub_audience_index_body import SubAudienceIndexBody
from sparkfly.models.sub_audience_index_data import SubAudienceIndexData
from sparkfly.models.subscription import Subscription
from sparkfly.models.subscription_request import SubscriptionRequest
from sparkfly.models.subscription_request_subscription import SubscriptionRequestSubscription
from sparkfly.models.subscription_response import SubscriptionResponse
from sparkfly.models.subscriptions_index_body import SubscriptionsIndexBody
from sparkfly.models.template import Template
from sparkfly.models.template2 import Template2
from sparkfly.models.template_templates_inner import TemplateTemplatesInner
from sparkfly.models.transaction_applied_credential import TransactionAppliedCredential
from sparkfly.models.transaction_campaign import TransactionCampaign
from sparkfly.models.transaction_campaign_offer import TransactionCampaignOffer
from sparkfly.models.transaction_item import TransactionItem
from sparkfly.models.transaction_redemption import TransactionRedemption
from sparkfly.models.transaction_response import TransactionResponse
from sparkfly.models.transaction_response_transaction import TransactionResponseTransaction
from sparkfly.models.transaction_totals import TransactionTotals
