# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.members_api import MembersApi


class TestMembersApi(unittest.IsolatedAsyncioTestCase):
    """MembersApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = MembersApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_member(self) -> None:
        """Test case for create_member

        Create a Member
        """
        pass

    async def test_create_profile(self) -> None:
        """Test case for create_profile

        Create/Update a Member Profile
        """
        pass

    async def test_delete_member(self) -> None:
        """Test case for delete_member

        Remove a Member
        """
        pass

    async def test_get_member(self) -> None:
        """Test case for get_member

        Find a Member
        """
        pass

    async def test_get_profile(self) -> None:
        """Test case for get_profile

        Retrieve a Member Profile
        """
        pass

    async def test_list_members(self) -> None:
        """Test case for list_members

        List Members
        """
        pass

    async def test_register_member(self) -> None:
        """Test case for register_member

        Register a New Member
        """
        pass

    async def test_search_members(self) -> None:
        """Test case for search_members

        Search for a Member
        """
        pass

    async def test_update_member(self) -> None:
        """Test case for update_member

        Update a Member
        """
        pass


if __name__ == '__main__':
    unittest.main()
