# coding: utf-8

"""
    Core Operations

    The Sparkfly Platform provides a full lifecycle for promotions and rewards from creation to distribution to settlement. The platform integrates in real-time at the point-of-sale and provides item level discounting and tracking. The capabilities of the Sparkfly Platform are available through the use of the Sparkfly Platform API.  The Sparkfly documentation site is under development. If the documentation you're after isn't available here, please contact support@sparkfly.com and we will get you what you need.

    The version of the OpenAPI document: 1.0
    Contact: support@sparkfly.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sparkfly.api.event_notifications_api import EventNotificationsApi


class TestEventNotificationsApi(unittest.IsolatedAsyncioTestCase):
    """EventNotificationsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = EventNotificationsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_create_callback(self) -> None:
        """Test case for create_callback

        Create Callback
        """
        pass

    async def test_create_subscription(self) -> None:
        """Test case for create_subscription

        Create Subscription
        """
        pass

    async def test_delete_callback(self) -> None:
        """Test case for delete_callback

        Delete Callback
        """
        pass

    async def test_delete_subscription(self) -> None:
        """Test case for delete_subscription

        Delete Subscription
        """
        pass

    async def test_get_callback(self) -> None:
        """Test case for get_callback

        Get Callback by ID
        """
        pass

    async def test_get_subscription(self) -> None:
        """Test case for get_subscription

        Get Subscription by ID
        """
        pass

    async def test_list_callbacks(self) -> None:
        """Test case for list_callbacks

        List Callbacks
        """
        pass

    async def test_list_subscriptions(self) -> None:
        """Test case for list_subscriptions

        List Subscriptions
        """
        pass


if __name__ == '__main__':
    unittest.main()
